



xmind2json is fork from xmindparser(https://github.com/tobyqin/xmindparser), a tool to help you convert xmind file to programmable data type, e.g. json, xml.
Now support XMind 8.

Quikly Start
-------------
    ➜ pip3 install xmind2json
    Collecting xmind2json
    Installing collected packages: xmind2json
    Successfully installed xmind2json-1.0.11

    ➜ xmind2json /Documents/test.xmind
    Generated: /Documents/test.json


Change Log
----------



1.1.0

- Fork from github.com/tobyqin/xmindparser.
- Support xmind 8 file type.
- Default convert to json type file.
- Output json file can contain non-ASCII characters.
